==> zigen.plugin.db_1.0.2.jar: src/zigen/plugin/db/ui/views/internal/SQLCodeConfiguration.java <==
/*
 * 쐬: 2005/04/03
 * 쌠: Copyright (c) 2005 ZIGEN
 * CZXFCommon Public License - v 1.0
 * Fhttp://www.eclipse.org/legal/cpl-v10.html
 */
package zigen.plugin.db.ui.views.internal;

import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.text.IDocument;
import org.eclipse.jface.text.TextAttribute;
import org.eclipse.jface.text.contentassist.ContentAssistant;
import org.eclipse.jface.text.contentassist.IContentAssistant;
import org.eclipse.jface.text.presentation.IPresentationReconciler;
import org.eclipse.jface.text.presentation.PresentationReconciler;
import org.eclipse.jface.text.rules.BufferedRuleBasedScanner;
import org.eclipse.jface.text.rules.DefaultDamagerRepairer;
import org.eclipse.jface.text.rules.Token;
import org.eclipse.jface.text.source.ISourceViewer;
import org.eclipse.jface.text.source.SourceViewerConfiguration;

import zigen.plugin.db.DbPlugin;
import zigen.plugin.db.preference.CodeAssistPreferencePage;
import zigen.plugin.db.preference.SQLEditorPreferencePage;
import zigen.plugin.db.ui.contentassist.SQLContentAssistantProcessor2;

/**
 * SQLCodeConfigurationNX.
 * 
 * @author ZIGEN
 * @version 1.0
 * @since JDK1.4 history Symbol Date Person Note [1] 2005/03/10 ZIGEN create.
 * 
 */
public class SQLCodeConfiguration extends SourceViewerConfiguration {

	private SQLKeywordScanner keyWorkScanner;

	private ColorManager colorManager;

	private PresentationReconciler reconciler;

	private IPreferenceStore preferenceStore;

	/**
	 * RXgN^
	 * 
	 * @param colorManager
	 */
	public SQLCodeConfiguration(ColorManager colorManager) {
		this.colorManager = colorManager;
		this.preferenceStore = DbPlugin.getDefault().getPreferenceStore();
	}

	protected SQLKeywordScanner getSQLKeywordScanner() {
		if (keyWorkScanner == null) {
			keyWorkScanner = new SQLKeywordScanner(colorManager);
		} else {
			// ǉ 2007/04/24 zigen
			keyWorkScanner.initialize();
		}
		return keyWorkScanner;
	}

	public String[] getConfiguredContentTypes(ISourceViewer sourceViewer) {
		return new String[] {
				IDocument.DEFAULT_CONTENT_TYPE,
				SQLPartitionScanner.SQL_COMMENT,
				SQLPartitionScanner.SQL_STRING
		};
	}

	static class SingleTokenScanner extends BufferedRuleBasedScanner {
		public SingleTokenScanner(TextAttribute attribute) {
			setDefaultReturnToken(new Token(attribute));
		}
	};

	// protected void TextWidgetConfig(StyledText text) {
	//
	// preferenceStore = DbPlugin.getDefault().getPreferenceStore();
	//
	// //Color color =
	// Display.getCurrent().getSystemColor(SWT.COLOR_DARK_GREEN);
	// //sqlViewer.getTextWidget().setBackground(color);
	// }

	// \p\bh
	// I[o[Ch
	public IPresentationReconciler getPresentationReconciler(ISourceViewer sourceViewer) {
		// \RTC[̍쐬
		reconciler = new PresentationReconciler();
		InitializeDamagerRepairer();
		return reconciler;
	}

	/** F̐ݒύXꍇɂ̃\bhĂяo܂ */
	public void updatePreferences(IDocument document) {

		getSQLKeywordScanner().initialize();

		// Rg̃X^Cݒ
		NonRuleBasedDamagerRepairer commentDR = new NonRuleBasedDamagerRepairer(new TextAttribute(colorManager.getColor(SQLEditorPreferencePage.P_COLOR_COMMENT)));
		commentDR.setDocument(document);

		reconciler.setDamager(commentDR, SQLPartitionScanner.SQL_COMMENT);
		reconciler.setRepairer(commentDR, SQLPartitionScanner.SQL_COMMENT);

		// 񃊃ẽX^Cݒ
		NonRuleBasedDamagerRepairer stringDR = new NonRuleBasedDamagerRepairer(new TextAttribute(colorManager.getColor(SQLEditorPreferencePage.P_COLOR_STRING)));
		stringDR.setDocument(document);

		reconciler.setDamager(stringDR, SQLPartitionScanner.SQL_STRING);
		reconciler.setRepairer(stringDR, SQLPartitionScanner.SQL_STRING);

		// ftHg̈̃X^Cݒ

		// DefaultDamagerRepairer defaultDR = new
		// DefaultDamagerRepairer(getSQLKeywordScanner());
		// reconciler.setDamager(keywordDR, IDocument.DEFAULT_CONTENT_TYPE);
		// reconciler.setRepairer(keywordDR, IDocument.DEFAULT_CONTENT_TYPE);
		//	
		// NonRuleBasedDamagerRepairer defaultDR = new
		// NonRuleBasedDamagerRepairer(
		// new TextAttribute(colorManager
		// .getColor(SQLEditorPreferencePage.P_COLOR_DEFAULT)));
		// defaultDR.setDocument(document);
		//
		// reconciler.setDamager(defaultDR, IDocument.DEFAULT_CONTENT_TYPE);
		// reconciler.setRepairer(defaultDR, IDocument.DEFAULT_CONTENT_TYPE);

	}

	private void InitializeDamagerRepairer() {

		// Rg̃X^Cݒ
		DefaultDamagerRepairer commentDR = new DefaultDamagerRepairer(new SingleTokenScanner(new TextAttribute(colorManager.getColor(SQLEditorPreferencePage.P_COLOR_COMMENT))));
		reconciler.setDamager(commentDR, SQLPartitionScanner.SQL_COMMENT);
		reconciler.setRepairer(commentDR, SQLPartitionScanner.SQL_COMMENT);

		// 񃊃ẽX^Cݒ
		DefaultDamagerRepairer stringDR = new DefaultDamagerRepairer(new SingleTokenScanner(new TextAttribute(colorManager.getColor(SQLEditorPreferencePage.P_COLOR_STRING))));
		reconciler.setDamager(stringDR, SQLPartitionScanner.SQL_STRING);
		reconciler.setRepairer(stringDR, SQLPartitionScanner.SQL_STRING);

		// ftHg̈̃X^Cݒ
		DefaultDamagerRepairer keywordDR = new DefaultDamagerRepairer(getSQLKeywordScanner());
		reconciler.setDamager(keywordDR, IDocument.DEFAULT_CONTENT_TYPE);
		reconciler.setRepairer(keywordDR, IDocument.DEFAULT_CONTENT_TYPE);

	}

	// RecAVXgp̃I[oCh\bh
	public IContentAssistant getContentAssistant(ISourceViewer sourceViewer) {
		ContentAssistant assistant = new ContentAssistant();

		assistant.setDocumentPartitioning(getConfiguredDocumentPartitioning(sourceViewer));
		// IContentAssistProcessor p = new SQLCompletionProcessor();
		// assistant.setContentAssistProcessor(p,
		// IDocument.DEFAULT_CONTENT_TYPE);

		// (JavaCC)
		// SQLContentAssistantProcessor processor = new
		// SQLContentAssistantProcessor();

		// V(蓮)
		SQLContentAssistantProcessor2 processor = new SQLContentAssistantProcessor2();
		assistant.setContentAssistProcessor(processor, IDocument.DEFAULT_CONTENT_TYPE);

		// IInformationControlCreator̐ݒ
		assistant.setInformationControlCreator(getInformationControlCreator(sourceViewer));

		// ANeBx[VLɂꍇtrue
		assistant.enableAutoActivation(true);

		int delayTime = preferenceStore.getInt(CodeAssistPreferencePage.P_SQL_CODE_ASSIST_AUTO_ACTIVATE_DELAY_TIME);
		// ANeBx[V܂ł̎
		assistant.setAutoActivationDelay(delayTime);

		// ₪PȂꍇ́AIɌ}ꍇtrue
		assistant.enableAutoInsert(true);

		// //assistant.install(sourceViewer);
		return assistant;
	}

	/*
	 * ҏW public IAutoEditStrategy[] getAutoEditStrategies(ISourceViewer
	 * sourceViewer, String contentType) { IAutoEditStrategy[] parentStrategies =
	 * super.getAutoEditStrategies(sourceViewer, contentType);
	 * IAutoEditStrategy[] newStrategies = new
	 * IAutoEditStrategy[parentStrategies.length+1];
	 * System.arraycopy(parentStrategies, 0, newStrategies, 0,
	 * parentStrategies.length); newStrategies[newStrategies.length-1] = new
	 * SQLAutoEditStrategy();
	 * 
	 * return newStrategies;
	 *  }
	 */

	// public IContentAssistant getContentAssistant(ISourceViewer sourceViewer)
	// {
	// ContentAssistant assistant= new ContentAssistant();
	// assistant.setDocumentPartitioning(getConfiguredDocumentPartitioning(sourceViewer));
	//
	// IContentAssistProcessor processor= new XMLCompletionProcessor();
	// assistant.setContentAssistProcessor(processor,
	// IDocument.DEFAULT_CONTENT_TYPE);
	// assistant.setContentAssistProcessor(processor,
	// XMLPartitionScanner.XML_TAG);
	//
	// assistant.setContextInformationPopupOrientation(IContentAssistant.CONTEXT_INFO_ABOVE);
	// assistant.setInformationControlCreator(getInformationControlCreator(sourceViewer));
	//
	// return assistant;
	// }

}

==> zigen.plugin.db_1.0.3.jar: src/zigen/plugin/db/ui/views/internal/SQLCodeConfiguration.java <==
/*
 * 쐬: 2005/04/03
 * 쌠: Copyright (c) 2005 ZIGEN
 * CZXFCommon Public License - v 1.0
 * Fhttp://www.eclipse.org/legal/cpl-v10.html
 */
package zigen.plugin.db.ui.views.internal;

import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.text.IDocument;
import org.eclipse.jface.text.TextAttribute;
import org.eclipse.jface.text.contentassist.ContentAssistant;
import org.eclipse.jface.text.contentassist.IContentAssistant;
import org.eclipse.jface.text.presentation.IPresentationReconciler;
import org.eclipse.jface.text.presentation.PresentationReconciler;
import org.eclipse.jface.text.rules.BufferedRuleBasedScanner;
import org.eclipse.jface.text.rules.DefaultDamagerRepairer;
import org.eclipse.jface.text.rules.Token;
import org.eclipse.jface.text.source.ISourceViewer;
import org.eclipse.jface.text.source.SourceViewerConfiguration;

import zigen.plugin.db.DbPlugin;
import zigen.plugin.db.preference.CodeAssistPreferencePage;
import zigen.plugin.db.preference.SQLEditorPreferencePage;
import zigen.plugin.db.ui.contentassist.SQLContentAssistantProcessor2;

/**
 * SQLCodeConfigurationNX.
 * 
 * @author ZIGEN
 * @version 1.0
 * @since JDK1.4 history Symbol Date Person Note [1] 2005/03/10 ZIGEN create.
 * 
 */
public class SQLCodeConfiguration extends SourceViewerConfiguration {

	private SQLKeywordScanner keyWorkScanner;

	private ColorManager colorManager;

	private PresentationReconciler reconciler;

	private IPreferenceStore preferenceStore;

	public SQLCodeConfiguration(ColorManager colorManager) {
		this.colorManager = colorManager;
		this.preferenceStore = DbPlugin.getDefault().getPreferenceStore();
	}

	

//	protected SQLKeywordScanner getSQLKeywordScanner() {
//		if (keyWorkScanner == null) {
//			keyWorkScanner = new SQLKeywordScanner(colorManager);
//		} else {
//			// ǉ 2007/04/24 zigen
//			keyWorkScanner.initialize();
//		}
//		return keyWorkScanner;
//	}

	protected SQLKeywordScanner getSQLKeywordScanner() {
		if (keyWorkScanner == null) {
			keyWorkScanner = new SQLKeywordScanner(colorManager);
		}else{
			// ǉ 2007/04/24 zigen
			keyWorkScanner.initialize();
		}
		return keyWorkScanner;
	}

	
	public String[] getConfiguredContentTypes(ISourceViewer sourceViewer) {
		return new String[] {
				IDocument.DEFAULT_CONTENT_TYPE,
				SQLPartitionScanner.SQL_COMMENT,
				SQLPartitionScanner.SQL_STRING
		};
	}

	static class SingleTokenScanner extends BufferedRuleBasedScanner {
		public SingleTokenScanner(TextAttribute attribute) {
			setDefaultReturnToken(new Token(attribute));
		}
	};

	// protected void TextWidgetConfig(StyledText text) {
	//
	// preferenceStore = DbPlugin.getDefault().getPreferenceStore();
	//
	// //Color color =
	// Display.getCurrent().getSystemColor(SWT.COLOR_DARK_GREEN);
	// //sqlViewer.getTextWidget().setBackground(color);
	// }

	// \p\bh
	// I[o[Ch
	public IPresentationReconciler getPresentationReconciler(ISourceViewer sourceViewer) {
		// \RTC[̍쐬
		reconciler = new PresentationReconciler();
		InitializeDamagerRepairer();
		return reconciler;
	}

	/** F̐ݒύXꍇɂ̃\bhĂяo܂ */
	public void updatePreferences(IDocument document) {

		getSQLKeywordScanner().initialize();

		// Rg̃X^Cݒ
		NonRuleBasedDamagerRepairer commentDR = new NonRuleBasedDamagerRepairer(new TextAttribute(colorManager.getColor(SQLEditorPreferencePage.P_COLOR_COMMENT)));
		commentDR.setDocument(document);

		reconciler.setDamager(commentDR, SQLPartitionScanner.SQL_COMMENT);
		reconciler.setRepairer(commentDR, SQLPartitionScanner.SQL_COMMENT);

		// 񃊃ẽX^Cݒ
		NonRuleBasedDamagerRepairer stringDR = new NonRuleBasedDamagerRepairer(new TextAttribute(colorManager.getColor(SQLEditorPreferencePage.P_COLOR_STRING)));
		stringDR.setDocument(document);

		reconciler.setDamager(stringDR, SQLPartitionScanner.SQL_STRING);
		reconciler.setRepairer(stringDR, SQLPartitionScanner.SQL_STRING);

		// ftHg̈̃X^Cݒ

		// DefaultDamagerRepairer defaultDR = new
		// DefaultDamagerRepairer(getSQLKeywordScanner());
		// reconciler.setDamager(keywordDR, IDocument.DEFAULT_CONTENT_TYPE);
		// reconciler.setRepairer(keywordDR, IDocument.DEFAULT_CONTENT_TYPE);
		//	

//		// L̐FftHgɂȂȂ߁ARg
//		NonRuleBasedDamagerRepairer defaultDR = new NonRuleBasedDamagerRepairer(new TextAttribute(colorManager.getColor(SQLEditorPreferencePage.P_COLOR_DEFAULT)));
//		defaultDR.setDocument(document);
//		reconciler.setDamager(defaultDR, IDocument.DEFAULT_CONTENT_TYPE);
//		reconciler.setRepairer(defaultDR, IDocument.DEFAULT_CONTENT_TYPE);
//		// ܂

	}

	private void InitializeDamagerRepairer() {

		// Rg̃X^Cݒ
		DefaultDamagerRepairer commentDR = new DefaultDamagerRepairer(new SingleTokenScanner(new TextAttribute(colorManager.getColor(SQLEditorPreferencePage.P_COLOR_COMMENT))));
		reconciler.setDamager(commentDR, SQLPartitionScanner.SQL_COMMENT);
		reconciler.setRepairer(commentDR, SQLPartitionScanner.SQL_COMMENT);

		// 񃊃ẽX^Cݒ
		DefaultDamagerRepairer stringDR = new DefaultDamagerRepairer(new SingleTokenScanner(new TextAttribute(colorManager.getColor(SQLEditorPreferencePage.P_COLOR_STRING))));
		reconciler.setDamager(stringDR, SQLPartitionScanner.SQL_STRING);
		reconciler.setRepairer(stringDR, SQLPartitionScanner.SQL_STRING);

		// ftHg̈̃X^Cݒ
		DefaultDamagerRepairer keywordDR = new DefaultDamagerRepairer(getSQLKeywordScanner());
		reconciler.setDamager(keywordDR, IDocument.DEFAULT_CONTENT_TYPE);
		reconciler.setRepairer(keywordDR, IDocument.DEFAULT_CONTENT_TYPE);

	}

	// RecAVXgp̃I[oCh\bh
	public IContentAssistant getContentAssistant(ISourceViewer sourceViewer) {
		ContentAssistant assistant = new ContentAssistant();

		assistant.setDocumentPartitioning(getConfiguredDocumentPartitioning(sourceViewer));
		// IContentAssistProcessor p = new SQLCompletionProcessor();
		// assistant.setContentAssistProcessor(p,
		// IDocument.DEFAULT_CONTENT_TYPE);

		// (JavaCC)
		// SQLContentAssistantProcessor processor = new
		// SQLContentAssistantProcessor();

		// V(蓮)
		SQLContentAssistantProcessor2 processor = new SQLContentAssistantProcessor2();
		assistant.setContentAssistProcessor(processor, IDocument.DEFAULT_CONTENT_TYPE);

		// IInformationControlCreator̐ݒ
		assistant.setInformationControlCreator(getInformationControlCreator(sourceViewer));

		// ANeBx[VLɂꍇtrue
		assistant.enableAutoActivation(true);

		int delayTime = preferenceStore.getInt(CodeAssistPreferencePage.P_SQL_CODE_ASSIST_AUTO_ACTIVATE_DELAY_TIME);
		// ANeBx[V܂ł̎
		assistant.setAutoActivationDelay(delayTime);

		// ₪PȂꍇ́AIɌ}ꍇtrue
		assistant.enableAutoInsert(true);

		// //assistant.install(sourceViewer);
		return assistant;
	}

	/*
	 * ҏW public IAutoEditStrategy[] getAutoEditStrategies(ISourceViewer
	 * sourceViewer, String contentType) { IAutoEditStrategy[] parentStrategies =
	 * super.getAutoEditStrategies(sourceViewer, contentType);
	 * IAutoEditStrategy[] newStrategies = new
	 * IAutoEditStrategy[parentStrategies.length+1];
	 * System.arraycopy(parentStrategies, 0, newStrategies, 0,
	 * parentStrategies.length); newStrategies[newStrategies.length-1] = new
	 * SQLAutoEditStrategy();
	 * 
	 * return newStrategies; }
	 */

	// public IContentAssistant getContentAssistant(ISourceViewer sourceViewer)
	// {
	// ContentAssistant assistant= new ContentAssistant();
	// assistant.setDocumentPartitioning(getConfiguredDocumentPartitioning(sourceViewer));
	//
	// IContentAssistProcessor processor= new XMLCompletionProcessor();
	// assistant.setContentAssistProcessor(processor,
	// IDocument.DEFAULT_CONTENT_TYPE);
	// assistant.setContentAssistProcessor(processor,
	// XMLPartitionScanner.XML_TAG);
	//
	// assistant.setContextInformationPopupOrientation(IContentAssistant.CONTEXT_INFO_ABOVE);
	// assistant.setInformationControlCreator(getInformationControlCreator(sourceViewer));
	//
	// return assistant;
	// }
}
